@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -217,7 +217,7 @@ class PredictionServiceAsyncClient:
         *,
         name: str = None,
         payload: data_items.ExamplePayload = None,
-        params: Sequence[prediction_service.PredictRequest.ParamsEntry] = None,
+        params: Mapping[str, str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -260,14 +260,13 @@ class PredictionServiceAsyncClient:
         -  A row with column values matching the columns of the model,
            up to 5MB. Not available for FORECASTING ``prediction_type``.
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1
 
-            def sample_predict():
+            async def sample_predict():
                 # Create a client
-                client = automl_v1.PredictionServiceClient()
+                client = automl_v1.PredictionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 payload = automl_v1.ExamplePayload()
@@ -279,7 +278,7 @@ class PredictionServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.predict(request=request)
+                response = await client.predict(request=request)
 
                 # Handle the response
                 print(response)
@@ -304,7 +303,7 @@ class PredictionServiceAsyncClient:
                 This corresponds to the ``payload`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            params (:class:`Sequence[google.cloud.automl_v1.types.PredictRequest.ParamsEntry]`):
+            params (:class:`Mapping[str, str]`):
                 Additional domain-specific parameters, any string must
                 be up to 25000 characters long.
 
@@ -387,7 +386,12 @@ class PredictionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -399,7 +403,7 @@ class PredictionServiceAsyncClient:
         name: str = None,
         input_config: io.BatchPredictInputConfig = None,
         output_config: io.BatchPredictOutputConfig = None,
-        params: Sequence[prediction_service.BatchPredictRequest.ParamsEntry] = None,
+        params: Mapping[str, str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -425,14 +429,13 @@ class PredictionServiceAsyncClient:
         -  AutoML Natural Language Sentiment Analysis
         -  AutoML Tables
 
-
         .. code-block:: python
 
             from google.cloud import automl_v1
 
-            def sample_batch_predict():
+            async def sample_batch_predict():
                 # Create a client
-                client = automl_v1.PredictionServiceClient()
+                client = automl_v1.PredictionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 input_config = automl_v1.BatchPredictInputConfig()
@@ -452,7 +455,7 @@ class PredictionServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -483,7 +486,7 @@ class PredictionServiceAsyncClient:
                 This corresponds to the ``output_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            params (:class:`Sequence[google.cloud.automl_v1.types.BatchPredictRequest.ParamsEntry]`):
+            params (:class:`Mapping[str, str]`):
                 Additional domain-specific parameters for the
                 predictions, any string must be up to 25000 characters
                 long.
@@ -627,7 +630,12 @@ class PredictionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -649,7 +657,9 @@ class PredictionServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-automl",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-automl",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
