@@ -43,7 +43,7 @@ class PredictRequest(proto.Message):
             Required. Payload to perform a prediction on.
             The payload must match the problem type that the
             model was trained to solve.
-        params (Sequence[google.cloud.automl_v1beta1.types.PredictRequest.ParamsEntry]):
+        params (Mapping[str, str]):
             Additional domain-specific parameters, any string must be up
             to 25000 characters long.
 
@@ -68,9 +68,20 @@ class PredictRequest(proto.Message):
                TablesAnnotation. The default is false.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    payload = proto.Field(proto.MESSAGE, number=2, message=data_items.ExamplePayload,)
-    params = proto.MapField(proto.STRING, proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    payload = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=data_items.ExamplePayload,
+    )
+    params = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=3,
+    )
 
 
 class PredictResponse(proto.Message):
@@ -90,7 +101,7 @@ class PredictResponse(proto.Message):
             -  For Text Extraction: If the input is a .pdf file, the
                OCR'ed text will be provided in
                [document_text][google.cloud.automl.v1beta1.Document.document_text].
-        metadata (Sequence[google.cloud.automl_v1beta1.types.PredictResponse.MetadataEntry]):
+        metadata (Mapping[str, str]):
             Additional domain-specific prediction response metadata.
 
             -  For Image Object Detection: ``max_bounding_box_count`` -
@@ -110,12 +121,20 @@ class PredictResponse(proto.Message):
     """
 
     payload = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=annotation_payload.AnnotationPayload,
+        proto.MESSAGE,
+        number=1,
+        message=annotation_payload.AnnotationPayload,
     )
     preprocessed_input = proto.Field(
-        proto.MESSAGE, number=3, message=data_items.ExamplePayload,
+        proto.MESSAGE,
+        number=3,
+        message=data_items.ExamplePayload,
+    )
+    metadata = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
     )
-    metadata = proto.MapField(proto.STRING, proto.STRING, number=2,)
 
 
 class BatchPredictRequest(proto.Message):
@@ -132,7 +151,7 @@ class BatchPredictRequest(proto.Message):
         output_config (google.cloud.automl_v1beta1.types.BatchPredictOutputConfig):
             Required. The Configuration specifying where
             output predictions should be written.
-        params (Sequence[google.cloud.automl_v1beta1.types.BatchPredictRequest.ParamsEntry]):
+        params (Mapping[str, str]):
             Required. Additional domain-specific parameters for the
             predictions, any string must be up to 25000 characters long.
 
@@ -212,14 +231,25 @@ class BatchPredictRequest(proto.Message):
                returned. Value in 0 to 1 range. Default is 0.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     input_config = proto.Field(
-        proto.MESSAGE, number=3, message=io.BatchPredictInputConfig,
+        proto.MESSAGE,
+        number=3,
+        message=io.BatchPredictInputConfig,
     )
     output_config = proto.Field(
-        proto.MESSAGE, number=4, message=io.BatchPredictOutputConfig,
+        proto.MESSAGE,
+        number=4,
+        message=io.BatchPredictOutputConfig,
+    )
+    params = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=5,
     )
-    params = proto.MapField(proto.STRING, proto.STRING, number=5,)
 
 
 class BatchPredictResult(proto.Message):
@@ -229,7 +259,7 @@ class BatchPredictResult(proto.Message):
     [PredictionService.BatchPredict][google.cloud.automl.v1beta1.PredictionService.BatchPredict].
 
     Attributes:
-        metadata (Sequence[google.cloud.automl_v1beta1.types.BatchPredictResult.MetadataEntry]):
+        metadata (Mapping[str, str]):
             Additional domain-specific prediction response metadata.
 
             -  For Image Object Detection: ``max_bounding_box_count`` -
@@ -241,7 +271,11 @@ class BatchPredictResult(proto.Message):
                have been returned.
     """
 
-    metadata = proto.MapField(proto.STRING, proto.STRING, number=1,)
+    metadata = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=1,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
